@@ -1,7 +1,7 @@
 from arc.middleware import Middleware
 from arc.defaults import DefaultMiddleware, DefaultExceptionHandler
 from jinja2.loaders import FileSystemLoader
-from webob import Request, Response
+from starlette.requests import Request
 import uvicorn
 from parse import parse
 from jinja2 import Environment, FileSystemLoader
@@ -16,73 +16,72 @@ class App:
     """
     The base App object. This object creates a WSGI application, and is used as the base object for creating routes, views, 
     templating, and more. Basic usage is as the following:: 
-    
+
     from arc import App
-    
+
     app = App("app")
-    
+
     @app.route("/")
     def index(req, res):
         res.text = 'Hello, World'
-    
+
     if __name__ == "__main__":
         app.run()
-    
+
     The app has several parameters.
-    
+
     ..name ::
         This paramter is used to specifiy the apps name. It is required, and has to be the same as the variable name
         you assigned the App class to.
-        
+
         app = App("app")
-        
-    
+
+
     ..templates_dir ::
         This parameter is used to specify the directory that jinja loads its HTML templates from. Its defaulted to 
         the 'templates' directory, but you can change it as the following::
-        
+
         app = App(templates_dir="public")
-        
+
     ..static_dir ::
         This parameter is used to specify the directory that static files are served from. Its defaulted to the
         'static' folder. You can change it as the following::
-        
+
         app = App(static_dir="css")
-        
+
     ..exception_handler ::
         This parameter is used to specify a custom exception handler for the app to use instead of the default
         one. It uses the base AppException class. It's defaulted to None, which causes the app to use the
         default exception handler. It can be changed as the following::
-        
+
         app = App(exception_handler=CustomExceptionHandler)
-        
+
     ..host ::
         This parameter is used to specify the host that the app will run on. Its defaulted 
         to '127.0.0.1'. It can be changed as the following::
-        
+
         app = App(host="181.177.121.773")
-        
+
     ..port ::
         This parameter is used to specify which port the app will listen on. Its defaulted to 
         port `5000`. You can change it as the following::
 
         app = App(port=8000)
-    
+
     ..default_middleware
         This parameter specifies whether the app should use the default middleware, which logs requests and
         responses into the console. Its set to True by default. You can change it as the following::
-        
+
         app = App(default_middleware=False)
     """
-    def __init__(self, name, templates_dir="templates", static_dir="static", exception_handler=None, host="127.0.0.1", port=5000, default_middleware=True):
+
+    def __init__(self, templates_dir="templates", static_dir="static", exception_handler=None, host="127.0.0.1", port=5000, default_middleware=True):
         self.routes = {}
-        
-        self.name = name
-        
-        #The host
+
+        # The host
         self.host = host
-        
-        #The port
+
+        # The port
         self.port = port
 
         self.templates_dir = templates_dir
@@ -104,32 +103,24 @@ class App:
 
         self.collections = []
 
-
-
-
-    def wsgi_app(self, environ, start_response):
-        request = Request(environ)
+    async def wsgi_app(self, scope, recieve, send):
+        request = Request(scope, recieve=recieve)
 
         response = self.handle_request(request)
 
-        return response(environ, start_response)
+        await response(scope, recieve, send)
 
-    def __call__(self, environ, start_response):
-        path_info = environ["PATH_INFO"]
+    def __call__(self, scope, recieve, send):
+        path_info = scope["path"]
 
-        if path_info.startswith("/static") or path_info.startswith("static"):
-            environ["PATH_INFO"] = path_info[len("/static"):]
-            return self.whitenoise(environ, start_response)
+        # if path_info.startswith("/static") or path_info.startswith("static"):
+        #     scope["PATH_INFO"] = path_info[len("/static"):]
+        #     return self.whitenoise(environ, start_response)
 
-        return self.middleware(environ, start_response)
+        return self.middleware(scope, recieve, send)
 
     def handle_request(self, request):
-        response = Response()
-
-        self.cur_req = request
-        self.cur_resp = response
-
-        handler, kwargs = self.find_handler(request_path=request.path)
+        handler, kwargs = self.find_handler(request_path=request.url.path)
 
         try:
             if handler is not None:
@@ -139,19 +130,18 @@ class App:
                         raise AttributeError(
                             "Method not allowed", request.method)
 
-                handler(request, response, **kwargs)
+                response = handler(request, **kwargs)
             else:
-                self.default_response(response)
+                self.default_response()
 
         except Exception as e:
             error = traceback.format_exc()
-            self.exception_handler.handle_error(request, response, error)
+            self.exception_handler.handle_error(request, error)
 
         return response
 
-    def default_response(self, response):
-        response.status_code = 404
-        self.exception_handler.handle_404(response)
+    def default_response(self):
+        self.exception_handler.handle_404()
 
     def find_handler(self, request_path):
         for path, handler in self.routes.items():
@@ -223,4 +213,5 @@ class App:
     def run(self):
         print(f"[INFO] Running on http://{self.host}:{self.port}")
         print(f"[INFO] Press CTRL + C to stop")
-        uvicorn.run(self, host="127.0.0.1", port=5000, log_level="error", interface="wsgi")
+        uvicorn.run(self, host="127.0.0.1", port=5000,
+                    log_level="critical", interface="wsgi")
